package NUREG::Automation::FontManager;
{
  $NUREG::Automation::FontManager::VERSION = '0.03';
}
use strict;
use warnings;

#
# Mit Schriften richtig umgehen
#  - Liste von Schrift-Namen (suchen am xs-Fonts) ?
#  - Verzeichnis mit Schrift-Dateien
#




1;
